@@ -43,12 +43,15 @@ This API needs serious cleaning up:
 #include "todo.h"
 
 #include <QDateTime>
+#include <QIcon>
 #include <QObject>
 #include <QTimeZone>
 
 /** Namespace for all KCalendarCore types. */
 namespace KCalendarCore
 {
+Q_NAMESPACE_EXPORT(KCALENDARCORE_EXPORT)
+
 class CalFilter;
 class Person;
 class ICalFormat;
@@ -82,6 +85,7 @@ enum TodoSortField {
     TodoSortPercentComplete, /**< Sort Todos by percentage completed */
     TodoSortSummary, /**< Sort Todos alphabetically, by summary */
     TodoSortCreated, /**< Sort Todos chronologically, by creation date */
+    TodoSortCategories, /**< Sort Todos by categories (tags) @since 5.83 */
 };
 
 /**
@@ -93,6 +97,16 @@ enum JournalSortField {
     JournalSortSummary, /**< Sort Journals alphabetically, by summary */
 };
 
+/**
+  The calendar's access mode, i.e. whether it can be written to or is read only.
+  @since 5.85
+*/
+enum AccessMode {
+    ReadOnly,
+    ReadWrite,
+};
+Q_ENUM_NS(AccessMode)
+
 /**
   @brief
   Represents the main calendar class.
@@ -119,7 +133,11 @@ class KCALENDARCORE_EXPORT Calendar : public QObject, public CustomProperties, p
 {
     Q_OBJECT
     Q_PROPERTY(QString productId READ productId WRITE setProductId) // clazy:exclude=qproperty-without-notify
-    Q_PROPERTY(KCalendarCore::Person owner READ owner WRITE setOwner)
+    Q_PROPERTY(KCalendarCore::Person owner READ owner WRITE setOwner NOTIFY ownerChanged)
+    Q_PROPERTY(QString id READ id WRITE setId NOTIFY idChanged)
+    Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
+    Q_PROPERTY(QIcon icon READ icon WRITE setIcon NOTIFY iconChanged)
+    Q_PROPERTY(KCalendarCore::AccessMode accessMode READ accessMode WRITE setAccessMode NOTIFY accessModeChanged)
 
 public:
     /**
@@ -262,6 +280,63 @@ public:
     */
     Q_REQUIRED_RESULT bool isModified() const;
 
+    /**
+     * A unique identifier for this calendar.
+     * @since 5.85
+     * @see setId()
+     */
+    QString id() const;
+
+    /**
+     * set a unique identifier for this calendar.
+     * @since 5.85
+     * @see id()
+     */
+    void setId(const QString &id);
+
+    /**
+     * The user-visible name for this calendar.
+     * @since 5.85
+     * @see setName()
+     */
+    QString name() const;
+
+    /**
+     * Set the user-visible name for this calendar.
+     * @since 5.85
+     * @see name()
+     */
+    void setName(const QString &name);
+
+    /**
+     * This calendar's icon.
+     * @since 5.85
+     * @see setIconName()
+     */
+    QIcon icon() const;
+
+    /**
+     * Set this calendar's icon.
+     * @since 5.85
+     * @see icon()
+     */
+    void setIcon(const QIcon &icon);
+
+    /**
+     * This calendar's AccessMode, i.e. whether it is writable or read-only.
+     * Defaults to ReadWrite.
+     * @since 5.85
+     * @see setAccessMode()
+     */
+    AccessMode accessMode() const;
+
+    /**
+     * Set this calendar's AccessMode, i.e. whether it is writable or read-only.
+     * @since 5.85
+     * @see accessMode()
+     */
+    void setAccessMode(const AccessMode mode);
+
     /**
       Clears out the current calendar, freeing all used memory etc.
     */
@@ -309,7 +384,7 @@ public:
     virtual void startBatchAdding();
 
     /**
-       Tells the Calendar that you stoped adding a batch of incidences.
+       Tells the Calendar that you stopped adding a batch of incidences.
 
         @see startBatchAdding()
      */
@@ -622,6 +697,7 @@ public:
     */
     virtual bool deleteEventInstances(const Event::Ptr &event) = 0;
 
+#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
     /**
       Sort a list of Events.
 
@@ -630,8 +706,30 @@ public:
       @param sortDirection specifies the SortDirection.
 
       @return a list of Events sorted as specified.
+
+      @deprecated since 5.95 Use the sortEvents(Event::List &&eventList, EventSortField sortField, SortDirection sortDirection)
+      overload instead. In the common case that you are sorting a list in-place, wrapping the @p eventList
+      argument with std::move will be all that's needed. In the less common case you actually want a copy,
+      create that explicitly first.
     */
+    KCALENDARCORE_DEPRECATED_VERSION(
+        5,
+        95,
+        "Use sortEvents(Event::List &&eventList, EventSortField sortField, SortDirection sortDirection); see API docs for details.")
     static Event::List sortEvents(const Event::List &eventList, EventSortField sortField, SortDirection sortDirection);
+#endif
+    /**
+      Sort a list of Events.
+
+      @param eventList the list of events that should be sorted. The list is sorted in place and returned.
+      @param sortField specifies the EventSortField.
+      @param sortDirection specifies the SortDirection.
+
+      @return a list of Events sorted as specified.
+      @since 5.95
+    */
+    static Event::List sortEvents(Event::List &&eventList, EventSortField sortField, SortDirection sortDirection);
+
     /**
       Returns a sorted, filtered list of all Events for this Calendar.
 
@@ -694,6 +792,7 @@ public:
     */
     virtual Event::List rawEvents(EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending) const = 0;
 
+#if KCALENDARCORE_BUILD_DEPRECATED_SINCE(5, 95)
     /**
       Returns an unfiltered list of all Events which occur on the given
       timestamp.
@@ -702,8 +801,12 @@ public:
 
       @return the list of unfiltered Events occurring on the specified
       timestamp.
+
+      @deprecated since 5.95 use rawEventsForDate(dt.date(), dt.timeZone()) overload instead.
     */
+    KCALENDARCORE_DEPRECATED_VERSION(5, 95, "Use rawEventsForDate(dt.date(), dt.timeZone()) insead")
     virtual Event::List rawEventsForDate(const QDateTime &dt) const = 0;
+#endif
 
     /**
       Returns an unfiltered list of all Events occurring within a date range.
@@ -819,6 +922,7 @@ public:
     */
     virtual bool deleteTodoInstances(const Todo::Ptr &todo) = 0;
 
+#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
     /**
       Sort a list of Todos.
 
@@ -827,8 +931,29 @@ public:
       @param sortDirection specifies the SortDirection.
 
       @return a list of Todos sorted as specified.
+
+      @deprecated since 5.95 Use the sortTodos(Todo::List &&todoList, TodoSortField sortField, SortDirection sortDirection)
+      overload instead. In the common case that you are sorting a list in-place, wrapping the @p todoList
+      argument with std::move will be all that's needed. In the less common case you actually want a copy,
+      create that explicitly first.
     */
+    KCALENDARCORE_DEPRECATED_VERSION(5,
+                                     95,
+                                     "Use sortTodos(Todo::List &&todoList, TodoSortField sortField, SortDirection sortDirection); see API docs for details.")
     static Todo::List sortTodos(const Todo::List &todoList, TodoSortField sortField, SortDirection sortDirection);
+#endif
+    /**
+      Sort a list of Todos.
+
+      @param todoList the list of todos that should be sorted. The list is sorted in place and returned.
+      @param sortField specifies the TodoSortField.
+      @param sortDirection specifies the SortDirection.
+
+      @return a list of Todos sorted as specified.
+
+      @since 5.95
+    */
+    static Todo::List sortTodos(Todo::List &&todoList, TodoSortField sortField, SortDirection sortDirection);
 
     /**
       Returns a sorted, filtered list of all Todos for this Calendar.
@@ -980,6 +1105,7 @@ public:
     */
     virtual bool deleteJournalInstances(const Journal::Ptr &journal) = 0;
 
+#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
     /**
       Sort a list of Journals.
 
@@ -988,8 +1114,30 @@ public:
       @param sortDirection specifies the SortDirection.
 
       @return a list of Journals sorted as specified.
+
+      @deprecated since 5.95 Use the sortJournals(Journal::List &&journalList, JournalSortField sortField, SortDirection sortDirection)
+      overload instead. In the common case that you are sorting a list in-place, wrapping the @p journalList
+      argument with std::move will be all that's needed. In the less common case you actually want a copy,
+      create that explicitly first.
     */
+    KCALENDARCORE_DEPRECATED_VERSION(
+        5,
+        95,
+        "Use sortJournals(Journal::List &&journalList, JournalSortField sortField, SortDirection sortDirection); see API docs for details.")
     static Journal::List sortJournals(const Journal::List &journalList, JournalSortField sortField, SortDirection sortDirection);
+#endif
+    /**
+      Sort a list of Journals.
+
+      @param journalList the list of journals that should be sorted. The list is sorted in place and returned.
+      @param sortField specifies the JournalSortField.
+      @param sortDirection specifies the SortDirection.
+
+      @return a list of Journals sorted as specified.
+      @since 5.95
+    */
+    static Journal::List sortJournals(Journal::List &&journalList, JournalSortField sortField, SortDirection sortDirection);
+
     /**
       Returns a sorted, filtered list of all Journals for this Calendar.
 
@@ -1106,7 +1254,7 @@ public:
        Returns a list of incidences that have a relation of RELTYPE parent
        to incidence @p uid.
 
-       @param uid The parent identifier whos children we want to obtain.
+       @param uid The parent identifier whose children we want to obtain.
     */
     Incidence::List relations(const QString &uid) const;
 
@@ -1300,8 +1448,8 @@ protected:
       @param alarms is a List of Alarms to be appended onto.
       @param incidence is a pointer to an Incidence containing the Alarm
       to be appended.
-      @param from is the lower range of the next Alarm repitition.
-      @param to is the upper range of the next Alarm repitition.
+      @param from is the lower range of the next Alarm repetition.
+      @param to is the upper range of the next Alarm repetition.
     */
     void appendAlarms(Alarm::List &alarms, const Incidence::Ptr &incidence, const QDateTime &from, const QDateTime &to) const;
 
@@ -1311,8 +1459,8 @@ protected:
       @param alarms is a List of Alarms to be appended onto.
       @param incidence is a pointer to an Incidence containing the Alarm
       to be appended.
-      @param from is the lower range of the next Alarm repitition.
-      @param to is the upper range of the next Alarm repitition.
+      @param from is the lower range of the next Alarm repetition.
+      @param to is the upper range of the next Alarm repetition.
     */
     void appendRecurringAlarms(Alarm::List &alarms, const Incidence::Ptr &incidence, const QDateTime &from, const QDateTime &to) const;
 
@@ -1346,6 +1494,41 @@ Q_SIGNALS:
      */
     void filterChanged();
 
+    /**
+     * Emitted when the id changes.
+     * @since 5.85
+     * @see id()
+     */
+    void idChanged();
+
+    /**
+     * Emitted when the name changes.
+     * @since 5.85
+     * @see name()
+     */
+    void nameChanged();
+
+    /**
+     * Emitted when the icon name changes.
+     * @since 5.85
+     * @see icon()
+     */
+    void iconChanged();
+
+    /**
+     * Emitted when the AccessMode changes.
+     * @since 5.85
+     * @see accessMode()
+     */
+    void accessModeChanged();
+
+    /**
+     * Emitted when the owner changes.
+     * @since 5.85
+     * @see owner()
+     */
+    void ownerChanged();
+
 private:
     friend class ICalFormat;
 
